@@ -6,10 +6,11 @@ import subprocess
 import timeit
 from pathlib import Path
 
-import atom3.database as db
-import atom3.sequence as sequ
 import pandas as pd
 import parallel as par
+
+import atom3.database as db
+import atom3.sequence as sequ
 from atom3.utils import extract_hmm_profile, slice_list
 
 
@@ -317,11 +318,6 @@ def _al2co(clustal_in, al2co_out):
             f_out.write('================= END CALL =================\n')
 
 
-def format_pdb_code_for_inputs(pdb_code: str, source_type: str):
-    """Format given PDB code for prediction inputs."""
-    return pdb_code[1:3] if source_type.lower() == 'input' else pdb_code.upper()
-
-
 def map_all_protrusion_indices(psaia_dir, psaia_config_file, pdb_dataset, pkl_dataset,
                                pruned_dataset, output_dir, source_type):
     ext = '.pkl'
@@ -346,13 +342,17 @@ def map_all_protrusion_indices(psaia_dir, psaia_config_file, pdb_dataset, pkl_da
     produced_filenames = [path.as_posix() for path in Path(produced_filenames_path).rglob('*.tbl')]
     produced_keys = [db.get_pdb_code(x) for x in produced_filenames]
     work_keys = [key for key, pdb_code in zip(requested_keys, requested_pdb_codes) if pdb_code not in produced_keys]
+    format_pdb_code_for_inputs = lambda pdb_code, source_type: pdb_code[1:3] \
+        if source_type.lower() in ['db5', 'input'] \
+        else pdb_code.upper()
     if source_type.lower() == 'rcsb' or source_type.lower() == 'casp_capri':
         work_filenames = [os.path.join(pdb_dataset, db.get_pdb_code(work_key)[1:3], work_key)
                           for work_key in work_keys]
     else:
         work_filenames = [os.path.join(pdb_dataset,
                                        format_pdb_code_for_inputs(db.get_pdb_code(work_key), source_type),
-                                       work_key) for work_key in work_keys]
+                                       work_key)
+                          for work_key in work_keys]
 
     # Remove any duplicate filenames
     work_filenames = list(set(work_filenames))
@@ -444,14 +444,13 @@ def map_all_profile_hmms(pkl_dataset, pruned_dataset, output_dir, hhsuite_db, nu
         produced_filenames = db.get_structures_filenames(output_dir, extension='.pkl')
         produced_keys = [db.get_pdb_name(x) for x in produced_filenames]
         work_keys = [key for key in requested_keys if key not in produced_keys]
-        if source_type.lower() == 'rcsb' or source_type.lower() == 'casp_capri':
-            work_filenames = [os.path.join(pkl_dataset, db.get_pdb_code(work_key)[1:3], work_key + ext)
-                              for work_key in work_keys]
-        else:
-            work_filenames = [os.path.join(pkl_dataset,
-                                           format_pdb_code_for_inputs(db.get_pdb_code(work_key)[1:3], source_type),
-                                           work_key + ext)
-                              for work_key in work_keys]
+        establish_pdb_code_case = lambda pdb_code, source_type: pdb_code.lower() \
+            if source_type.lower() == 'casp_capri' \
+            else pdb_code.upper()
+        work_filenames = [os.path.join(pkl_dataset,
+                                       establish_pdb_code_case(db.get_pdb_code(work_key), source_type)[1:3],
+                                       work_key + ext)
+                          for work_key in work_keys]
 
         # Remove any duplicate filenames
         work_filenames = list(set(work_filenames))
